@@ -1,26 +1,12 @@
 from datetime import datetime
 import json
-import os
+import pkg_resources
 
-# env = os.environ.get('APP_ENV', 'dev')
-
-# if env == 'prod':
-#     config_path = 'prod_config.json'
-# else:
-#     config_path = 'dev_config.json'
-
-# # Load the configuration file
-# with open(config_path, 'r') as f:
-#     config = json.load(f)
-
-# Get the absolute path of the 'common' directory in production
-# common_dir = os.path.abspath(os.path.join(
-#     os.getcwd(), config['constants_path']))
-
-here = os.path.abspath(os.path.dirname(__file__))
+constants_file = pkg_resources.resource_filename(
+    __name__, 'constants.json')
 
 # Load the constants from the JSON file
-with open(os.path.join(here, 'constants.json'), 'r') as f:
+with open(constants_file, 'r') as f:
     constants = json.load(f)
 
 
